@@ -94,19 +94,19 @@ def invoke_backend_service_as_proxy(method, function_path, json_data=dict(), req
 
         response_json = json.loads(response_data)
 
-        if response.status is 200 || response.status is 204:
+        if response.status is 200 or response.status is 204:
             if response.status is 200:
                 if response_token and proxy_server.USER_TOKEN not in response_json:
                     raise WsResponseError('Server expected user token in response')
 
-                return response
             elif response.status is 204:
                 if response_token:
                     raise WsResponseError('Backend server didn\'t respond with a token')
 
             resp = HttpResponse(response_data, content_type='application/json')
-            for header in response.info().keys():
-                resp[header] = response.info()[header]    
+            for header, value in response.getheaders():
+                print value
+                resp[header] = value
 
             return resp
         else:
