@@ -8,16 +8,16 @@ import json
 def test(request):
     service_url = generate_service_url('/login')
     response = invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' }, request=request)
-    return HttpResponse(json.dumps(response), content_type='application/json')
+    print type(response)
+    return response
+
 
 @expose_service(['GET'], public=True)
 def test_error(request):
     service_url = generate_service_url('/login')
-    response = invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com' }, request=request)
-    return HttpResponse(json.dumps(response), content_type='application/json')
+    return invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com' }, request=request)
 
 @expose_service(['GET'])
 def test_token_validation(request):
     service_url = generate_service_url('/login')
-    response = invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' }, request=request)
-    return HttpResponse(json.dumps(response), content_type='application/json')
+    return invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' }, request=request)
